==> theme-bootstrap-1.0.119.tgz: package/src/components/icons/icon-wallet-service/icon-wallet-service.jsx <==
import React from 'react';

export function IconWalletService() {
  return (
    <svg version="1.1" id="icon-wallet-service" xmlns="http://www.w3.org/2000/svg" width="42" height="44" x="0px" y="0px" viewBox="0 0 42 44" style={{ enableBackground: 'new 0 0 42 44' }} xmlSpace="preserve">
      <g>
        <path className="st0" fill="#0BB37A" d="M38,8H6V5H0v33c0,2.2,1.8,4,4,4h34c2.2,0,4-1.8,4-4V12C42,9.8,40.2,8,38,8z" />
        <linearGradient id="icon-wallet-service-SVGID_1_" gradientUnits="userSpaceOnUse" x1="-2.6077" y1="8.0428" x2="27.8437" y2="29.9124">
          <stop offset="3.810975e-04" style={{ stopColor: '#FFFFFF' }} />
          <stop offset="1" style={{ stopColor: '#FFFFFF', stopOpacity: 0 }} />
        </linearGradient>
        <path className="st1" fill="url(#icon-wallet-service-SVGID_1_)" opacity="0.3" d="M38,8H6V5H0v33c0,2.2,1.8,4,4,4h34c2.2,0,4-1.8,4-4V12C42,9.8,40.2,8,38,8z" />
      </g>
      <g>
        <path className="st2" fill="#04D992" d="M39,29h3v-8h-3c-2.2,0-4,1.8-4,4v0C35,27.2,36.8,29,39,29z" />
      </g>
      <g>
        <path
          className="st4"
          fill="#FFFFFF"
          d="M19.1,20.8c0.5-0.6,1.4-0.6,2-0.1c0.1,0.1,0.1,0.1,0.2,0.2c2.5,2.1,4.1,3.6,4.7,4.5c0.6,0.9,0.8,2.1,0.8,3.2
          C26.5,32,23.3,34,20.4,34c-3.5,0-6.4-2.6-6.4-5.7h2.8c0,1.6,1.6,2.9,3.6,2.9c1.6,0,3.4-1.1,3.6-2.8c0-0.5-0.1-1.1-0.4-1.6
          c-0.4-0.7-3.2-3.1-4.1-3.8c-0.1,0-0.1-0.1-0.2-0.2C18.7,22.3,18.6,21.4,19.1,20.8L19.1,20.8z M21.6,29.2c0.5-0.6,0.5-1.5-0.1-2
          c-0.1-0.1-0.2-0.1-0.2-0.2c-0.9-0.8-3.7-3.1-4.1-3.8c-0.3-0.5-0.4-1-0.4-1.6c0.1-1.8,1.9-2.8,3.6-2.8c2,0,3.6,1.3,3.6,2.9h2.8
          c0-3.2-2.9-5.7-6.4-5.7c-2.9,0-6.1,2-6.4,5.4c-0.1,1.1,0.2,2.3,0.8,3.2c0.6,0.9,2.2,2.4,4.7,4.5c0,0,0.1,0.1,0.2,0.2
          C20.2,29.8,21.1,29.8,21.6,29.2L21.6,29.2z"
        />
      </g>
      <g>
        <path className="st5" fill="#93F5D1" d="M38,8H3C1.3,8,0,6.7,0,5v0c0-1.7,1.3-3,3-3h31c2.2,0,4,1.8,4,4v0.5V8z" />
        <linearGradient id="icon-wallet-service-SVGID_3_" gradientUnits="userSpaceOnUse" x1="19" y1="2.125" x2="19" y2="7.9388">
          <stop offset="3.810975e-04" style={{ stopColor: '#FFFFFF' }} />
          <stop offset="1" style={{ stopColor: '#FFFFFF', stopOpacity: 0 }} />
        </linearGradient>
        <path className="st6" fill="url(#icon-wallet-service-SVGID_3_)" opacity="0.2" d="M38,8H3C1.3,8,0,6.7,0,5v0c0-1.7,1.3-3,3-3h31c2.2,0,4,1.8,4,4v0.5V8z" />
      </g>
    </svg>
  );
}

==> theme-bootstrap-1.0.121.tgz: package/src/components/icons/icon-wallet-service/icon-wallet-service.jsx <==
import React from 'react';
import colors from '../../../theme/js/color-variables';

export function IconWalletService() {
  return (
    <svg version="1.1" id="icon-wallet-service" xmlns="http://www.w3.org/2000/svg" width="42" height="44" x="0px" y="0px" viewBox="0 0 42 44" style={{ enableBackground: 'new 0 0 42 44' }} xmlSpace="preserve">
      <g>
        <path className="st0" fill={colors.greenG40} d="M38,8H6V5H0v33c0,2.2,1.8,4,4,4h34c2.2,0,4-1.8,4-4V12C42,9.8,40.2,8,38,8z" />
        <linearGradient id="icon-wallet-service-SVGID_1_" gradientUnits="userSpaceOnUse" x1="-2.6077" y1="8.0428" x2="27.8437" y2="29.9124">
          <stop offset="3.810975e-04" style={{ stopColor: '#FFFFFF' }} />
          <stop offset="1" style={{ stopColor: '#FFFFFF', stopOpacity: 0 }} />
        </linearGradient>
        <path className="st1" fill="url(#icon-wallet-service-SVGID_1_)" opacity="0.3" d="M38,8H6V5H0v33c0,2.2,1.8,4,4,4h34c2.2,0,4-1.8,4-4V12C42,9.8,40.2,8,38,8z" />
      </g>
      <g>
        <path className="st2" fill={colors.greenG30} d="M39,29h3v-8h-3c-2.2,0-4,1.8-4,4v0C35,27.2,36.8,29,39,29z" />
      </g>
      <g>
        <path
          className="st4"
          fill="#FFFFFF"
          d="M19.1,20.8c0.5-0.6,1.4-0.6,2-0.1c0.1,0.1,0.1,0.1,0.2,0.2c2.5,2.1,4.1,3.6,4.7,4.5c0.6,0.9,0.8,2.1,0.8,3.2
          C26.5,32,23.3,34,20.4,34c-3.5,0-6.4-2.6-6.4-5.7h2.8c0,1.6,1.6,2.9,3.6,2.9c1.6,0,3.4-1.1,3.6-2.8c0-0.5-0.1-1.1-0.4-1.6
          c-0.4-0.7-3.2-3.1-4.1-3.8c-0.1,0-0.1-0.1-0.2-0.2C18.7,22.3,18.6,21.4,19.1,20.8L19.1,20.8z M21.6,29.2c0.5-0.6,0.5-1.5-0.1-2
          c-0.1-0.1-0.2-0.1-0.2-0.2c-0.9-0.8-3.7-3.1-4.1-3.8c-0.3-0.5-0.4-1-0.4-1.6c0.1-1.8,1.9-2.8,3.6-2.8c2,0,3.6,1.3,3.6,2.9h2.8
          c0-3.2-2.9-5.7-6.4-5.7c-2.9,0-6.1,2-6.4,5.4c-0.1,1.1,0.2,2.3,0.8,3.2c0.6,0.9,2.2,2.4,4.7,4.5c0,0,0.1,0.1,0.2,0.2
          C20.2,29.8,21.1,29.8,21.6,29.2L21.6,29.2z"
        />
      </g>
      <g>
        <path className="st5" fill={colors.greenG20} d="M38,8H3C1.3,8,0,6.7,0,5v0c0-1.7,1.3-3,3-3h31c2.2,0,4,1.8,4,4v0.5V8z" />
        <linearGradient id="icon-wallet-service-SVGID_3_" gradientUnits="userSpaceOnUse" x1="19" y1="2.125" x2="19" y2="7.9388">
          <stop offset="3.810975e-04" style={{ stopColor: '#FFFFFF' }} />
          <stop offset="1" style={{ stopColor: '#FFFFFF', stopOpacity: 0 }} />
        </linearGradient>
        <path className="st6" fill="url(#icon-wallet-service-SVGID_3_)" opacity="0.2" d="M38,8H3C1.3,8,0,6.7,0,5v0c0-1.7,1.3-3,3-3h31c2.2,0,4,1.8,4,4v0.5V8z" />
      </g>
    </svg>
  );
}
